@@ -2,8 +2,9 @@
 """
 This is the unittest for tee module.
 
-python -m unittest -v test_tee.py
-python -m pytest --cov-report term-missing -v tests/test_tee.py
+python -m unittest -v tests/test_tee.py
+python -m pytest --cov=pyjams --cov-report term-missing -v tests/test_tee.py
+
 """
 from __future__ import division, absolute_import, print_function
 import unittest
